Class: Dropsonde::Submitter::OpenTelemetry

Inherits:
Object
  • Object
show all
Defined in:
lib/dropsonde/submitter/open_telemetry.rb

Overview

This currently doesn’t actually exist. It’s just a placeholder for someday when it does exist!

Class Method Summary collapse

Class Method Details

.submit_report(options) ⇒ Object



6
7
8
9
# File 'lib/dropsonde/submitter/open_telemetry.rb', line 6

def self.submit_report(options)
  puts 'When Vox Pupuli has its own telemetry server, this will post there.'
  puts options.inspect
end